/**
 * Program: GOWControl.java
 * Comments: This is the central control program for the client side of
 * GOW.  This is the one you start to run the client.
 * It initializes all of the data and providea accessor methods for 
 * them.  It creates instances of the MyCharon and MyToolBar classes.  A
 * reference of GOWControl must be passed to MyToolBar so that it can 
 * obtain the data.
 * 
 * See the comments for the main method for details on command line 
 * arguments.
 */
package WebFlow.Control;

import java.net.*;
import java.io.*;
import WebFlow.*;
import WebFlow.event.*;
import WebFlow.Charon.*;
import WebFlow.ToolBar.*;
import org.omg.CORBA.*;

public class GOWControl {

    //Define here all of the data pieces that will need to be
    //made available to contained classes.  May want to set these in
    //a java properties file or in an xml configuration at some 
    //point.
    static URL target;
    String UrlString;
    String userName;
    String descDir="/app/gateway/apache_1.3.12/htdocs/GOW/WEB-INF/Descriptors/users/JSPClient/";
    String browserCmd="netscape http://localhost:8080/GOW/Generic/Main.jsp";
    String IorUrl;

    //classes
    //    MyCharon mycharon;
    MyToolBar mytoolbar;
    ORB orb;
    WebFlowContext master=null;

    /**------------------------------------------------------------
     * The constructor. Note I'm going to pass MyToolBar a 
     * reference to this GOWControl so that it can use the
     * accessor methods.
     *------------------------------------------------------------*/
    public GOWControl(String url, String Port) {
	UrlString=url;
	IorUrl=UrlString+"/GOW/IOR/master.txt";

	//Do the authentication
	//mycharon=new MyCharon(this, Port);
	//The following will be done inside MyCharon() later.
	String masterIOR=WebFlow.ClientUtils.getIORFromURL(IorUrl);
	orb=WebFlow.ClientUtils.initializeORB(masterIOR,orb);
	master=WebFlow.ClientUtils.getMasterServer(masterIOR,orb);
	userName="gateway";   //change to mycharon.getUserName();

	//Set up the visual display.
	mytoolbar=new MyToolBar(this);
	mytoolbar.pack();
	mytoolbar.show();
    }

    /**------------------------------------------------------------
     * The command line requires two arguments:
     * 1. The URL of the server file: http://localhost:8080
     * 2. The port you wish Charon to run over.
     *------------------------------------------------------------*/
    public static void main(String[] args) {
	if(args.length < 2) {
	    System.out.println(" ");
	    System.out.println("Usage: java WebFlow.Charon.Client url port");
	    System.out.println("where url is base url of the target server");
	    System.exit(0);
	}
	else {
	    String UrlString = args[0];
	    String Port=args[1];
	    
	    //This is some control code to make sure that all of the
	    //inputs are working OK.
 	    try {
		target = new URL(UrlString);
	    } catch (MalformedURLException e) {
		System.out.println(" ");
		System.out.println("The base url of the target server is incorrect");
		System.out.println(UrlString);
		if(!UrlString.startsWith("http")) {
		    System.out.println("must starts with http");
		}
		System.exit(0);
	    }
	    try {
		InputStream is = target.openStream();
		is.close();
	    } catch (IOException e) {
		System.out.println(" ");
		System.out.println("The target server seems to be down");
		System.out.println(UrlString);
		System.exit(0);
	    }
	    
	    //Everything is fine, so create a new GOWControl object.
	    new GOWControl(UrlString, Port); 
	    
	}
    }

    /**------------------------------------------------------------
     * The following are accessor methods for various pieces of
     * data and classes.  I hope the methods are self explanatory.
     *------------------------------------------------------------*/

    public String getUrlString() { return UrlString; }
    public String getDescDir() { return descDir; }
    public String getUserName() { return userName; }
    public String getBrowserCommand() { return browserCmd; }
    public String getIorUrl() { return IorUrl; }
    public ORB getOrb() { return orb; }
    public WebFlowContext getMaster() { return master; }
    
}










